@@ -20,9 +20,8 @@ store_aws_file_stage <- function(path) {
     store_aws_path_0.8.1(path), # targets 0.8.1 and under
     if_any(
       length(path) <= 2L, # targets 0.4.2 and under
-      path_scratch(
-        path_store = path_scratch_dir_cloud(),
-        paste0("targets_aws_file_", basename(store_aws_key(path)))
+      path_scratch_temp_network(
+        pattern = paste0("targets_aws_file_", basename(store_aws_key(path)))
       ),
       path[3]
     ),
@@ -50,7 +49,11 @@ store_hash_early.tar_aws_file <- function(store) { # nolint
   store$file$path <- store_aws_file_stage(store$file$path)
   on.exit(store$file$path <- old)
   tar_assert_path(store$file$path)
-  file_update_hash(store$file)
+  file_update_info(store$file)
+}
+
+#' @export
+store_hash_late.tar_aws_file <- function(store) { # nolint
 }
 
 #' @export
@@ -58,33 +61,21 @@ store_read_object.tar_aws_file <- function(store) {
   path <- store$file$path
   key <- store_aws_key(path)
   bucket <- store_aws_bucket(path)
-  scratch <- path_scratch(
-    path_store = path_scratch_dir_cloud(),
-    pattern = basename(store_aws_key(path))
-  )
+  scratch <- path_scratch_temp_network(pattern = basename(store_aws_key(path)))
   dir_create(dirname(scratch))
-  seconds_interval <- store$resources$network$seconds_interval %|||% 1
-  seconds_timeout <- store$resources$network$seconds_timeout %|||% 30
-  max_tries <- store$resources$network$max_tries %|||% Inf
-  verbose <- store$resources$network$verbose %|||% TRUE
-  retry_until_true(
-    ~{
-      aws_s3_download(
-        key = key,
-        bucket = bucket,
-        file = scratch,
-        region = store_aws_region(path),
-        version = store_aws_version(path),
-        args = store$resources$aws$args
-      )
-      TRUE
-    },
-    seconds_interval = seconds_interval,
-    seconds_timeout = seconds_timeout,
-    max_tries = max_tries,
-    catch_error = TRUE,
-    message = sprintf("Cannot download object %s from bucket %s", key, bucket),
-    verbose = verbose
+  aws <- store$resources$aws
+  aws_s3_download(
+    key = key,
+    bucket = bucket,
+    file = scratch,
+    region = store_aws_region(path),
+    endpoint = store_aws_endpoint(path),
+    version = store_aws_version(path),
+    args = aws$args,
+    max_tries = aws$max_tries,
+    seconds_timeout = aws$seconds_timeout,
+    close_connection = aws$close_connection,
+    s3_force_path_style = aws$s3_force_path_style
   )
   stage <- store_aws_file_stage(path)
   dir_create(dirname(stage))
