@@ -8,7 +8,7 @@ build_init <- function(
   capture_error <- function(condition) {
     state$error <- build_message(condition)
     state$error_class <- class(condition)
-    state$traceback <- build_traceback(condition, sys.calls())
+    state$traceback <- build_traceback(sys.calls())
     NULL
   }
   capture_warning <- function(condition) {
@@ -62,14 +62,7 @@ build_new <- function(object = NULL, metrics = NULL) {
 
 build_run_expr <- function(expr, envir, seed, packages, library) {
   load_packages(packages = packages, library = library)
-  if (!anyNA(seed)) {
-    # Borrowed from https://github.com/r-lib/withr/blob/main/R/seed.R
-    # under the MIT license. See the NOTICE file
-    # in the targets package source.
-    old_seed <- .GlobalEnv[[".Random.seed"]]
-    set.seed(seed)
-    on.exit(restore_seed(old_seed), add = TRUE)
-  }
+  tar_seed_set(seed = seed)
   build_eval_fce17be7(expr, envir)
 }
 
@@ -78,18 +71,10 @@ build_eval_fce17be7 <- function(expr, envir) {
   eval(expr = expr, envir = envir)
 }
 
-build_traceback <- function(condition, calls) {
-  UseMethod("build_traceback")
-}
-
-#' @export
-build_traceback.tar_condition_cancel <- function(condition, calls) {
-  NULL
-}
-
-#' @export
-build_traceback.default <- function(condition, calls) {
-  as.character(calls)
+build_traceback <- function(calls) {
+  trace <- tar_format_trace(calls)
+  limit <- max(grep(pattern = "build_eval_fce17be7", x = trace)) + 3L
+  trace[seq(from = limit, to = length(trace))]
 }
 
 build_message <- function(condition, prefix = character(0)) {
