@@ -9,18 +9,18 @@ forecast_class <- R6::R6Class(
   portable = FALSE,
   cloneable = FALSE,
   public = list(
-    dequeue = function() {
-      if (!is.null(self$queue)) {
-        message(self$queue, appendLF = FALSE)
-        self$queue <- NULL
+    flush_messages = function() {
+      if (!is.null(self$buffer)) {
+        message(self$buffer, appendLF = FALSE)
+        self$buffer <- NULL
       }
     },
     report_outdated = function(outdated) {
-      self$queue <- cli_forecast(outdated$cli_data(), print = FALSE)
+      self$buffer <- cli_forecast(outdated$cli_data(), print = FALSE)
       self$poll()
     },
     report_end = function(progress = NULL, seconds_elapsed = NULL) {
-      self$dequeue()
+      self$flush_messages()
       message("")
     }
   )
