@@ -35,7 +35,7 @@ metrics_outcome <- function(metrics) {
   if_any(
     metrics_has_cancel(metrics),
     "cancel",
-    if_any(metrics_has_error(metrics), "error", "built")
+    if_any(metrics_has_error(metrics), "error", "completed")
   )
 }
 
