@@ -47,7 +47,11 @@ is_internal_object <- function(object) {
 
 envir_deps <- function(name, envir, names) {
   value <- base::get(x = name, envir = envir, inherits = FALSE)
-  deps <- if_any(is.function(value), deps_function(value), character(0))
+  deps <- if_any(
+    is.function(value) && !is.primitive(value),
+    deps_function(value),
+    character(0)
+  )
   deps <- c(deps, name)
   intersect(deps, names)
 }
